"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var src_exports = {};
__export(src_exports, {
  default: () => src_default,
  transform: () => transform
});
module.exports = __toCommonJS(src_exports);

// src/transform.ts
var import_magic_string = __toESM(require("magic-string"), 1);

// src/constants.ts
var HTML_ELEMENT_TAGS = [
  "address",
  "article",
  "aside",
  "footer",
  "header",
  "h1",
  "h2",
  "h3",
  "h4",
  "h5",
  "h6",
  "hgroup",
  "main",
  "nav",
  "section",
  "blockquote",
  "dd",
  "div",
  "dl",
  "dt",
  "figcaption",
  "figure",
  "hr",
  "li",
  "menu",
  "ol",
  "p",
  "pre",
  "ul",
  "a",
  "abbr",
  "b",
  "font-weight",
  "bdi",
  "bdo",
  "br",
  "cite",
  "code",
  "data",
  "dfn",
  "em",
  "i",
  "kbd",
  "mark",
  "q",
  "rp",
  "ruby",
  "rt",
  "s",
  "samp",
  "small",
  "span",
  "strong",
  "sub",
  "sup",
  "time",
  "u",
  "var",
  "wbr",
  "area",
  "audio",
  "MediaStream",
  "img",
  "map",
  "track",
  "video",
  "embed",
  "iframe",
  "object",
  "picture",
  "source",
  "portal",
  "svg",
  "math",
  "canvas",
  "del",
  "ins",
  "caption",
  "col",
  "colgroup",
  "table",
  "tbody",
  "tr",
  "td",
  "tfoot",
  "th",
  "thead",
  "button",
  "datalist",
  "option",
  "fieldset",
  "label",
  "form",
  "input",
  "legend",
  "meter",
  "optgroup",
  "select",
  "output",
  "progress",
  "textarea",
  "details",
  "summary",
  "dialog",
  "slot",
  "template",
  "acronym",
  "bgsound",
  "big",
  "center",
  "content",
  "dir",
  "font",
  "frame",
  "frameset",
  "image",
  "marquee",
  "menuitem",
  "nobr",
  "noembed",
  "noframes",
  "param",
  "plaintext",
  "rb",
  "rtc",
  "shadow",
  "strike",
  "tt",
  "xmp"
];

// src/format.ts
var import_js_beautify = require("js-beautify");
function cssFormat(code, type = "space", indent = 2) {
  return (0, import_js_beautify.css_beautify)(code, {
    indent_size: indent,
    indent_with_tabs: type === "tab"
  });
}

// src/transform.ts
function transform(code, basic, options, id) {
  const { enableElementTag = false, enableUniversal = false } = options || {};
  const css = cssFormat(code);
  const s = new import_magic_string.default(css);
  let withHtmlElementTagsReg = "";
  if (enableElementTag)
    withHtmlElementTagsReg = `|\\b(${HTML_ELEMENT_TAGS.join("|")})\\b(.*)`;
  const universalSelectorReg = enableUniversal ? "|(?<=(\\*))(.*)" : "";
  const classSelectorReg = "(?<=^(\\.|\\#))(.*)";
  const regStr = `(${classSelectorReg}${universalSelectorReg}${withHtmlElementTagsReg})(?=\\s*\\{)`;
  const reg = new RegExp(regStr, "gm");
  const matches = Array.from(css.matchAll(reg));
  if (!matches.length)
    return;
  for (const match of matches) {
    const selector = match[0];
    const dot = match[2] || "";
    const universal = match[4] && enableUniversal ? match[4] || "" : "";
    const raw = `${universal}${dot}${selector}`;
    if (raw.includes(basic))
      continue;
    const offset = match.index > 0 ? 1 : 0;
    const start = match.index - offset;
    const end = start + selector.length + offset;
    const replacement = `${basic} ${raw}`;
    s.update(start, end, replacement);
  }
  return {
    code: s.toString(),
    map: s.generateMap({
      file: id,
      includeContent: true
    })
  };
}

// src/index.ts
function VitePluginBasicCssSelector(basic, options) {
  return {
    name: "vite-plugin-basic-css-selector",
    enforce: options == null ? void 0 : options.enforce,
    apply: options == null ? void 0 : options.apply,
    transform(code, id) {
      if (id.endsWith(".css"))
        return transform(code, basic, options, id);
    }
  };
}
var src_default = VitePluginBasicCssSelector;
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  transform
});
