// src/transform.ts
import MagicString from "magic-string";

// src/constants.ts
var HTML_ELEMENT_TAGS = [
  "address",
  "article",
  "aside",
  "footer",
  "header",
  "h1",
  "h2",
  "h3",
  "h4",
  "h5",
  "h6",
  "hgroup",
  "main",
  "nav",
  "section",
  "blockquote",
  "dd",
  "div",
  "dl",
  "dt",
  "figcaption",
  "figure",
  "hr",
  "li",
  "menu",
  "ol",
  "p",
  "pre",
  "ul",
  "a",
  "abbr",
  "b",
  "font-weight",
  "bdi",
  "bdo",
  "br",
  "cite",
  "code",
  "data",
  "dfn",
  "em",
  "i",
  "kbd",
  "mark",
  "q",
  "rp",
  "ruby",
  "rt",
  "s",
  "samp",
  "small",
  "span",
  "strong",
  "sub",
  "sup",
  "time",
  "u",
  "var",
  "wbr",
  "area",
  "audio",
  "MediaStream",
  "img",
  "map",
  "track",
  "video",
  "embed",
  "iframe",
  "object",
  "picture",
  "source",
  "portal",
  "svg",
  "math",
  "canvas",
  "del",
  "ins",
  "caption",
  "col",
  "colgroup",
  "table",
  "tbody",
  "tr",
  "td",
  "tfoot",
  "th",
  "thead",
  "button",
  "datalist",
  "option",
  "fieldset",
  "label",
  "form",
  "input",
  "legend",
  "meter",
  "optgroup",
  "select",
  "output",
  "progress",
  "textarea",
  "details",
  "summary",
  "dialog",
  "slot",
  "template",
  "acronym",
  "bgsound",
  "big",
  "center",
  "content",
  "dir",
  "font",
  "frame",
  "frameset",
  "image",
  "marquee",
  "menuitem",
  "nobr",
  "noembed",
  "noframes",
  "param",
  "plaintext",
  "rb",
  "rtc",
  "shadow",
  "strike",
  "tt",
  "xmp"
];

// src/format.ts
import { css_beautify } from "js-beautify";
function cssFormat(code, type = "space", indent = 2) {
  return css_beautify(code, {
    indent_size: indent,
    indent_with_tabs: type === "tab"
  });
}

// src/transform.ts
function transform(code, basic, options, id) {
  const { enableElementTag = false, enableUniversal = false } = options || {};
  const css = cssFormat(code);
  const s = new MagicString(css);
  let withHtmlElementTagsReg = "";
  if (enableElementTag)
    withHtmlElementTagsReg = `|\\b(${HTML_ELEMENT_TAGS.join("|")})\\b(.*)`;
  const universalSelectorReg = enableUniversal ? "|(?<=(\\*))(.*)" : "";
  const classSelectorReg = "(?<=^(\\.|\\#))(.*)";
  const regStr = `(${classSelectorReg}${universalSelectorReg}${withHtmlElementTagsReg})(?=\\s*\\{)`;
  const reg = new RegExp(regStr, "gm");
  const matches = Array.from(css.matchAll(reg));
  if (!matches.length)
    return;
  for (const match of matches) {
    const selector = match[0];
    const dot = match[2] || "";
    const universal = match[4] && enableUniversal ? match[4] || "" : "";
    const raw = `${universal}${dot}${selector}`;
    if (raw.includes(basic))
      continue;
    const offset = match.index > 0 ? 1 : 0;
    const start = match.index - offset;
    const end = start + selector.length + offset;
    const replacement = `${basic} ${raw}`;
    s.update(start, end, replacement);
  }
  return {
    code: s.toString(),
    map: s.generateMap({
      file: id,
      includeContent: true
    })
  };
}

// src/index.ts
function VitePluginBasicCssSelector(basic, options) {
  return {
    name: "vite-plugin-basic-css-selector",
    enforce: options == null ? void 0 : options.enforce,
    apply: options == null ? void 0 : options.apply,
    transform(code, id) {
      if (id.endsWith(".css"))
        return transform(code, basic, options, id);
    }
  };
}
var src_default = VitePluginBasicCssSelector;
export {
  src_default as default,
  transform
};
